from setuptools import setup

setup(name='funniestst',
      version='0.1',
      description='Jenos greater then Khan',
      url='http://github.com/shubhstiws',
      author='Shubhankar Tiwari',
      author_email='flyingcircus@example.com',
      license='MIT',
      packages=['funniestst'],
      zip_safe=False)